# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelpipelinerun/v1/modelpipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQgithub.com/metaprov/modelaapi/services/modelpipelinerun/v1/modelpipelinerun.proto\x12:github.com.metaprov.modelaapi.services.modelpipelinerun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\x8f\x02\n\x1cListModelPipelineRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12t\n\x06labels\x18\x02 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x01\n\x1dListModelPipelineRunsResponse\x12i\n\x11modelpipelineruns\x18\x01 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1a\n\x18ModelPipelineRunResponse\"\x85\x01\n\x1d\x43reateModelPipelineRunRequest\x12\x64\n\x10modelpipelinerun\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\" \n\x1e\x43reateModelPipelineRunResponse\"\xb5\x01\n\x1dUpdateModelPipelineRunRequest\x12\x64\n\x10modelpipelinerun\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\" \n\x1eUpdateModelPipelineRunResponse\"=\n\x1aGetModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x91\x01\n\x1bGetModelPipelineRunResponse\x12\x64\n\x10modelpipelinerun\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteModelPipelineRunResponse\"a\n\x1e\x41pproveModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\"!\n\x1f\x41pproveModelPipelineRunResponse\"^\n\x1b\x44\x65nyModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\"\x1e\n\x1c\x44\x65nyModelPipelineRunResponse\"\x1f\n\x1dPauseModelPipelineRunResponse\"?\n\x1cPauseModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1eResumeModelPipelineRunResponse\"@\n\x1dResumeModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1d\x41\x62ortModelPipelineRunResponse\"?\n\x1c\x41\x62ortModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xec\x14\n\x17ModelPipelineRunService\x12\xf7\x01\n\x15ListModelPipelineRuns\x12X.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest\x1aY.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/modelpipelineruns/{namespace}\x12\xf1\x01\n\x16\x43reateModelPipelineRun\x12Y.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.CreateModelPipelineRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.CreateModelPipelineRunResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/modelpipelineruns:\x01*\x12\xf8\x01\n\x13GetModelPipelineRun\x12V.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunRequest\x1aW.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunResponse\"0\x82\xd3\xe4\x93\x02*\x12(/v1/modelpipelineruns/{namespace}/{name}\x12\xb8\x02\n\x16UpdateModelPipelineRun\x12Y.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.UpdateModelPipelineRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.UpdateModelPipelineRunResponse\"g\x82\xd3\xe4\x93\x02\x61\x1a\\/v1/modelpipelineruns/{modelpipelinerun.metadata.namespace}/{modelpipelinerun.metadata.name}:\x01*\x12\x81\x02\n\x16\x44\x65leteModelPipelineRun\x12Y.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunResponse\"0\x82\xd3\xe4\x93\x02**(/v1/modelpipelineruns/{namespace}/{name}\x12\x8c\x02\n\x17\x41pproveModelPipelineRun\x12Z.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunRequest\x1a[.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunResponse\"8\x82\xd3\xe4\x93\x02\x32\x1a\x30/v1/modelpipelineruns/{namespace}/{name}:approve\x12\x80\x02\n\x14\x44\x65nyModelPipelineRun\x12W.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunResponse\"5\x82\xd3\xe4\x93\x02/\x1a-/v1/modelpipelineruns/{namespace}/{name}:deny\x12\x84\x02\n\x15\x41\x62ortModelPipelineRun\x12X.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunRequest\x1aY.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunResponse\"6\x82\xd3\xe4\x93\x02\x30\x1a./v1/modelpipelineruns/{namespace}/{name}:abort\x12\x84\x02\n\x15PauseModelPipelineRun\x12X.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunRequest\x1aY.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunResponse\"6\x82\xd3\xe4\x93\x02\x30\x1a./v1/modelpipelineruns/{namespace}/{name}:pause\x12\x88\x02\n\x16ResumeModelPipelineRun\x12Y.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunResponse\"7\x82\xd3\xe4\x93\x02\x31\x1a//v1/modelpipelineruns/{namespace}/{name}:resumeB<Z:github.com/metaprov/modelaapi/services/modelpipelinerun/v1b\x06proto3')



_LISTMODELPIPELINERUNSREQUEST = DESCRIPTOR.message_types_by_name['ListModelPipelineRunsRequest']
_LISTMODELPIPELINERUNSREQUEST_LABELSENTRY = _LISTMODELPIPELINERUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELPIPELINERUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelPipelineRunsResponse']
_MODELPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['ModelPipelineRunResponse']
_CREATEMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateModelPipelineRunRequest']
_CREATEMODELPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelPipelineRunResponse']
_UPDATEMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelPipelineRunRequest']
_UPDATEMODELPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelPipelineRunResponse']
_GETMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetModelPipelineRunRequest']
_GETMODELPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['GetModelPipelineRunResponse']
_DELETEMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelPipelineRunRequest']
_DELETEMODELPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelPipelineRunResponse']
_APPROVEMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['ApproveModelPipelineRunRequest']
_APPROVEMODELPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['ApproveModelPipelineRunResponse']
_DENYMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DenyModelPipelineRunRequest']
_DENYMODELPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['DenyModelPipelineRunResponse']
_PAUSEMODELPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['PauseModelPipelineRunResponse']
_PAUSEMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['PauseModelPipelineRunRequest']
_RESUMEMODELPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['ResumeModelPipelineRunResponse']
_RESUMEMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['ResumeModelPipelineRunRequest']
_ABORTMODELPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['AbortModelPipelineRunResponse']
_ABORTMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['AbortModelPipelineRunRequest']
ListModelPipelineRunsRequest = _reflection.GeneratedProtocolMessageType('ListModelPipelineRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELPIPELINERUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELPIPELINERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest)
  })
_sym_db.RegisterMessage(ListModelPipelineRunsRequest)
_sym_db.RegisterMessage(ListModelPipelineRunsRequest.LabelsEntry)

ListModelPipelineRunsResponse = _reflection.GeneratedProtocolMessageType('ListModelPipelineRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsResponse)
  })
_sym_db.RegisterMessage(ListModelPipelineRunsResponse)

ModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(ModelPipelineRunResponse)

CreateModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.CreateModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateModelPipelineRunRequest)

CreateModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.CreateModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateModelPipelineRunResponse)

UpdateModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.UpdateModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateModelPipelineRunRequest)

UpdateModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.UpdateModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateModelPipelineRunResponse)

GetModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetModelPipelineRunRequest)

GetModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(GetModelPipelineRunResponse)

DeleteModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteModelPipelineRunRequest)

DeleteModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteModelPipelineRunResponse)

ApproveModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ApproveModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(ApproveModelPipelineRunRequest)

ApproveModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ApproveModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(ApproveModelPipelineRunResponse)

DenyModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DenyModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DENYMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(DenyModelPipelineRunRequest)

DenyModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('DenyModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DENYMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(DenyModelPipelineRunResponse)

PauseModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('PauseModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(PauseModelPipelineRunResponse)

PauseModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('PauseModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(PauseModelPipelineRunRequest)

ResumeModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ResumeModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(ResumeModelPipelineRunResponse)

ResumeModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ResumeModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(ResumeModelPipelineRunRequest)

AbortModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('AbortModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(AbortModelPipelineRunResponse)

AbortModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('AbortModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(AbortModelPipelineRunRequest)

_MODELPIPELINERUNSERVICE = DESCRIPTOR.services_by_name['ModelPipelineRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/metaprov/modelaapi/services/modelpipelinerun/v1'
  _LISTMODELPIPELINERUNSREQUEST_LABELSENTRY._options = None
  _LISTMODELPIPELINERUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELPIPELINERUNSERVICE.methods_by_name['ListModelPipelineRuns']._options = None
  _MODELPIPELINERUNSERVICE.methods_by_name['ListModelPipelineRuns']._serialized_options = b'\202\323\344\223\002#\022!/v1/modelpipelineruns/{namespace}'
  _MODELPIPELINERUNSERVICE.methods_by_name['CreateModelPipelineRun']._options = None
  _MODELPIPELINERUNSERVICE.methods_by_name['CreateModelPipelineRun']._serialized_options = b'\202\323\344\223\002\032\"\025/v1/modelpipelineruns:\001*'
  _MODELPIPELINERUNSERVICE.methods_by_name['GetModelPipelineRun']._options = None
  _MODELPIPELINERUNSERVICE.methods_by_name['GetModelPipelineRun']._serialized_options = b'\202\323\344\223\002*\022(/v1/modelpipelineruns/{namespace}/{name}'
  _MODELPIPELINERUNSERVICE.methods_by_name['UpdateModelPipelineRun']._options = None
  _MODELPIPELINERUNSERVICE.methods_by_name['UpdateModelPipelineRun']._serialized_options = b'\202\323\344\223\002a\032\\/v1/modelpipelineruns/{modelpipelinerun.metadata.namespace}/{modelpipelinerun.metadata.name}:\001*'
  _MODELPIPELINERUNSERVICE.methods_by_name['DeleteModelPipelineRun']._options = None
  _MODELPIPELINERUNSERVICE.methods_by_name['DeleteModelPipelineRun']._serialized_options = b'\202\323\344\223\002**(/v1/modelpipelineruns/{namespace}/{name}'
  _MODELPIPELINERUNSERVICE.methods_by_name['ApproveModelPipelineRun']._options = None
  _MODELPIPELINERUNSERVICE.methods_by_name['ApproveModelPipelineRun']._serialized_options = b'\202\323\344\223\0022\0320/v1/modelpipelineruns/{namespace}/{name}:approve'
  _MODELPIPELINERUNSERVICE.methods_by_name['DenyModelPipelineRun']._options = None
  _MODELPIPELINERUNSERVICE.methods_by_name['DenyModelPipelineRun']._serialized_options = b'\202\323\344\223\002/\032-/v1/modelpipelineruns/{namespace}/{name}:deny'
  _MODELPIPELINERUNSERVICE.methods_by_name['AbortModelPipelineRun']._options = None
  _MODELPIPELINERUNSERVICE.methods_by_name['AbortModelPipelineRun']._serialized_options = b'\202\323\344\223\0020\032./v1/modelpipelineruns/{namespace}/{name}:abort'
  _MODELPIPELINERUNSERVICE.methods_by_name['PauseModelPipelineRun']._options = None
  _MODELPIPELINERUNSERVICE.methods_by_name['PauseModelPipelineRun']._serialized_options = b'\202\323\344\223\0020\032./v1/modelpipelineruns/{namespace}/{name}:pause'
  _MODELPIPELINERUNSERVICE.methods_by_name['ResumeModelPipelineRun']._options = None
  _MODELPIPELINERUNSERVICE.methods_by_name['ResumeModelPipelineRun']._serialized_options = b'\202\323\344\223\0021\032//v1/modelpipelineruns/{namespace}/{name}:resume'
  _LISTMODELPIPELINERUNSREQUEST._serialized_start=284
  _LISTMODELPIPELINERUNSREQUEST._serialized_end=555
  _LISTMODELPIPELINERUNSREQUEST_LABELSENTRY._serialized_start=510
  _LISTMODELPIPELINERUNSREQUEST_LABELSENTRY._serialized_end=555
  _LISTMODELPIPELINERUNSRESPONSE._serialized_start=558
  _LISTMODELPIPELINERUNSRESPONSE._serialized_end=721
  _MODELPIPELINERUNRESPONSE._serialized_start=723
  _MODELPIPELINERUNRESPONSE._serialized_end=749
  _CREATEMODELPIPELINERUNREQUEST._serialized_start=752
  _CREATEMODELPIPELINERUNREQUEST._serialized_end=885
  _CREATEMODELPIPELINERUNRESPONSE._serialized_start=887
  _CREATEMODELPIPELINERUNRESPONSE._serialized_end=919
  _UPDATEMODELPIPELINERUNREQUEST._serialized_start=922
  _UPDATEMODELPIPELINERUNREQUEST._serialized_end=1103
  _UPDATEMODELPIPELINERUNRESPONSE._serialized_start=1105
  _UPDATEMODELPIPELINERUNRESPONSE._serialized_end=1137
  _GETMODELPIPELINERUNREQUEST._serialized_start=1139
  _GETMODELPIPELINERUNREQUEST._serialized_end=1200
  _GETMODELPIPELINERUNRESPONSE._serialized_start=1203
  _GETMODELPIPELINERUNRESPONSE._serialized_end=1348
  _DELETEMODELPIPELINERUNREQUEST._serialized_start=1350
  _DELETEMODELPIPELINERUNREQUEST._serialized_end=1414
  _DELETEMODELPIPELINERUNRESPONSE._serialized_start=1416
  _DELETEMODELPIPELINERUNRESPONSE._serialized_end=1448
  _APPROVEMODELPIPELINERUNREQUEST._serialized_start=1450
  _APPROVEMODELPIPELINERUNREQUEST._serialized_end=1547
  _APPROVEMODELPIPELINERUNRESPONSE._serialized_start=1549
  _APPROVEMODELPIPELINERUNRESPONSE._serialized_end=1582
  _DENYMODELPIPELINERUNREQUEST._serialized_start=1584
  _DENYMODELPIPELINERUNREQUEST._serialized_end=1678
  _DENYMODELPIPELINERUNRESPONSE._serialized_start=1680
  _DENYMODELPIPELINERUNRESPONSE._serialized_end=1710
  _PAUSEMODELPIPELINERUNRESPONSE._serialized_start=1712
  _PAUSEMODELPIPELINERUNRESPONSE._serialized_end=1743
  _PAUSEMODELPIPELINERUNREQUEST._serialized_start=1745
  _PAUSEMODELPIPELINERUNREQUEST._serialized_end=1808
  _RESUMEMODELPIPELINERUNRESPONSE._serialized_start=1810
  _RESUMEMODELPIPELINERUNRESPONSE._serialized_end=1842
  _RESUMEMODELPIPELINERUNREQUEST._serialized_start=1844
  _RESUMEMODELPIPELINERUNREQUEST._serialized_end=1908
  _ABORTMODELPIPELINERUNRESPONSE._serialized_start=1910
  _ABORTMODELPIPELINERUNRESPONSE._serialized_end=1941
  _ABORTMODELPIPELINERUNREQUEST._serialized_start=1943
  _ABORTMODELPIPELINERUNREQUEST._serialized_end=2006
  _MODELPIPELINERUNSERVICE._serialized_start=2009
  _MODELPIPELINERUNSERVICE._serialized_end=4677
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.modelautobuilder.v1 import modelautobuilder_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2


class ModelAutobuilderServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModelAutobuilders = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService/ListModelAutobuilders',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.ListModelAutobuildersRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.ListModelAutobuildersResponse.FromString,
                )
        self.CreateModelAutobuilder = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService/CreateModelAutobuilder',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.CreateModelAutobuilderRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.CreateModelAutobuilderResponse.FromString,
                )
        self.GetModelAutobuilder = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService/GetModelAutobuilder',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.GetModelAutobuilderRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.GetModelAutobuilderResponse.FromString,
                )
        self.UpdateModelAutobuilder = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService/UpdateModelAutobuilder',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.UpdateModelAutobuilderRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.UpdateModelAutobuilderResponse.FromString,
                )
        self.DeleteModelAutobuilder = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService/DeleteModelAutobuilder',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.DeleteModelAutobuilderRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.DeleteModelAutobuilderResponse.FromString,
                )


class ModelAutobuilderServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListModelAutobuilders(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelAutobuilder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelAutobuilder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModelAutobuilder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModelAutobuilder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelAutobuilderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModelAutobuilders': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelAutobuilders,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.ListModelAutobuildersRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.ListModelAutobuildersResponse.SerializeToString,
            ),
            'CreateModelAutobuilder': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelAutobuilder,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.CreateModelAutobuilderRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.CreateModelAutobuilderResponse.SerializeToString,
            ),
            'GetModelAutobuilder': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelAutobuilder,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.GetModelAutobuilderRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.GetModelAutobuilderResponse.SerializeToString,
            ),
            'UpdateModelAutobuilder': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModelAutobuilder,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.UpdateModelAutobuilderRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.UpdateModelAutobuilderResponse.SerializeToString,
            ),
            'DeleteModelAutobuilder': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModelAutobuilder,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.DeleteModelAutobuilderRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.DeleteModelAutobuilderResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelAutobuilderService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListModelAutobuilders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService/ListModelAutobuilders',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.ListModelAutobuildersRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.ListModelAutobuildersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelAutobuilder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService/CreateModelAutobuilder',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.CreateModelAutobuilderRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.CreateModelAutobuilderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelAutobuilder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService/GetModelAutobuilder',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.GetModelAutobuilderRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.GetModelAutobuilderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModelAutobuilder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService/UpdateModelAutobuilder',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.UpdateModelAutobuilderRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.UpdateModelAutobuilderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModelAutobuilder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelautobuilder.v1.ModelAutobuilderService/DeleteModelAutobuilder',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.DeleteModelAutobuilderRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelautobuilder_dot_v1_dot_modelautobuilder__pb2.DeleteModelAutobuilderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
